get_internal_nodes: Helper function to get the internal nodes of a dendrogram and...

get_internal_nodesR Documentation

Helper function to get the internal nodes of a dendrogram and the leafs in each subtree

Description

Helper function to get the internal nodes of a dendrogram and the leafs in each subtree

Usage

get_internal_nodes(den, node, labels)

Arguments

den

dendrogram

node

character Node name

labels

character vector Leaf labels


numbat documentation built on Feb. 4, 2026, 9:07 a.m.