label_edges: Annotate the direct upstream or downstream mutations on the...

label_edgesR Documentation

Annotate the direct upstream or downstream mutations on the edges

Description

Annotate the direct upstream or downstream mutations on the edges

Usage

label_edges(G)

Arguments

G

igraph Mutation graph

Value

igraph Mutation graph


numbat documentation built on Feb. 4, 2026, 9:07 a.m.