pnorm.range.log: Get the total probability from a region of a normal pdf

pnorm.range.logR Documentation

Get the total probability from a region of a normal pdf

Description

Get the total probability from a region of a normal pdf

Usage

pnorm.range.log(lower, upper, mu, sd)

numbat documentation built on Feb. 4, 2026, 9:07 a.m.