transfer_links: Annotate the direct upstream or downstream node on the edges

View source: R/trees.R

transfer_linksR Documentation

Description

Annotate the direct upstream or downstream node on the edges

Usage

transfer_links(G)

Arguments

G

igraph Mutation graph

Value

igraph Mutation graph


numbat documentation built on Feb. 4, 2026, 9:07 a.m.